embassy-stm32

Crates

git

Versions

stm32c5a3zg

Flavors

ADC1

Struct ADC1 

pub struct ADC1 { /* private fields */ }
ADC1 peripheral

Implementations

Source

impl ADC1

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.